"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.genPulumiConfig = void 0;
const base_1 = require("@plutolang/base");
const aws_credentials_1 = require("./aws-credentials");
const aws_region_1 = require("./aws-region");
const pluto_config_1 = require("./pluto-config");
async function genPulumiConfig(sta) {
    const genFnMapping = {
        [base_1.PlatformType.AWS]: genPulumiConfigForAWS,
        [base_1.PlatformType.K8s]: genPulumiConfigForK8s,
        [base_1.PlatformType.AliCloud]: genPulumiConfigForAliCloud,
    };
    if (!(sta.platformType in genFnMapping)) {
        throw new Error("Not support this runtime.");
    }
    return await genFnMapping[sta.platformType](sta);
}
exports.genPulumiConfig = genPulumiConfig;
async function genPulumiConfigForAWS() {
    const region = await (0, aws_region_1.getAwsRegion)();
    if (region == undefined) {
        throw new Error("Please make sure to set your default region by setting the AWS_REGION environment variable first.");
    }
    let creds = await (0, aws_credentials_1.getAwsCredentialsFromLocal)();
    if (creds == undefined) {
        const plutoConfig = (0, pluto_config_1.readPlutoGlobalConfig)();
        if (!("userId" in plutoConfig)) {
            console.info("There is not any AWS credentials on your machine. We will guide you through the process of creating an AWS Role. We will open a new tab in your browser to create a CloudFormation stack. Please complete the creation process there.");
            const userId = await (0, aws_credentials_1.createPlutoRole)();
            plutoConfig["userId"] = userId;
            (0, pluto_config_1.savePlutoGlobalConfig)(plutoConfig);
        }
        creds = await (0, aws_credentials_1.getAwsCredentialsFromAuthService)(plutoConfig["userId"]);
        if (process.env.DEBUG) {
            console.debug("Got credentials from auth service.");
        }
    }
    process.env["AWS_ACCESS_KEY_ID"] = creds.accessKeyId;
    process.env["AWS_SECRET_ACCESS_KEY"] = creds.secretAccessKey;
    if (creds.sessionToken) {
        process.env["AWS_SESSION_TOKEN"] = creds.sessionToken;
    }
    return {
        "aws:region": { value: region },
    };
}
async function genPulumiConfigForK8s(sta) {
    const configMap = {};
    for (const [key, value] of Object.entries(sta.configs)) {
        if (key.startsWith("kubernetes:")) {
            configMap[key] = { value };
        }
    }
    return configMap;
}
async function genPulumiConfigForAliCloud(sta) {
    sta;
    if (!process.env.ALICLOUD_REGION ||
        !process.env.ALICLOUD_ACCESS_KEY ||
        !process.env.ALICLOUD_SECRET_KEY) {
        throw new Error("You need to set the ALICLOUD_REGION, ALICLOUD_ACCESS_KEY, and ALICLOUD_SECRET_KEY environment variables.");
    }
    return {};
}
//# sourceMappingURL=gen-pulumi-config.js.map